/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-07-20 16:30+0200\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.0.7\n"

, "Alarm for event \"%1$s\" at %2$s"
: "Termin-Erinnerung für \"%1$s\" am %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "Einladung zum Termin  \"%1$s\" am %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: "Ressource \"%1$s\" wurde für \"%2$s\" am %3$s gebucht"

, "Event \"%1$s\" at %2$s has been canceled"
: "Termin \"%1$s\" am %2$s wurde abgesagt"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: "Der Termin \"%1$s\" wurde von %2$s auf %3$s verlegt"

, "Event \"%1$s\" at %2$s has been updated"
: "Der Termin \"%1$s\" am %2$s wurde verändert"

, "%1$s accepted event \"%2$s\" at %3$s"
: "Zusage von %1$s für den Termin \"%2$s\" am  %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "Absage von %1$s für den Termin \"%2$s\" am  %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "Vorläufige Zusage von %1$s für den Termin \"%2$s\" am  %3$s"

, "No response from %1$s for event \"%2$s\" at %3$s"
: "Keine Antwort von %1$s für den Termin \"%2$s\" am  %3$s"

, "Attendee changes for event \"%1$s\" at %2$s"
: "Geänderte Teilnehmer beim Termin  \"%1$s\" am %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: "Vorläufigkeits Benachrichtigung für den Termin \"%1$s\" am %2$s"

, "Resource Management"
: "Ressourcen Verwaltung"

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: "Die neue Wiederholungsregel ist nicht erfüllbar. Bitte ändern sie die Regel."

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: "Dieser Kontakt ist Teilnehmer einer Termin-Umfrage und wurde vom System automatisch angelegt."

, "Attendance Confirmation for Poll \"%1$s\""
: "Teilnahmebestätigung für die Termin-Umfrage „%1$s“"

, "%1$s is scheduled for %2$s"
: "%1$s ist auf %2$s gelegt"

, "Different Calendar"
: "Anderer Kalender"

, "Exdate container move are not allowed"
: "Verscheiben eines Ausnahmen Containers ist nicht erlaubt"

, "Invalid URL given"
: "Ungültige URL angegeben"

, "The URL you used is invalid. Please use a valid one!"
: "Die verwendete URL ist ungültig. Bitte verwende eine gültige URL."

, "Switch to public poll"
: "Zur öffentlichen Umfrage wechseln"

, "Welcome {name}"
: "Willkommen {name}"

, "This is a closed poll. No Attendee can be added."
: "Dies ist eine geschlossene Umfrage. Es können keine Teilnehmer hinzugefügt werden."

, "This poll is closed already"
: "Diese Umfrage ist bereits abgeschlossen"

, "I am not {name}"
: "Ich bin nicht {name}"

, "Login"
: "Anmelden"

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Calendar, Calendars"
: [
  "Kalender"
 ,"Kalender"

]
, "First name, ĺast name"
: "Vorname, Nachname"

, "E-Mail address"
: "E-Mail Adresse"

, "Cancel"
: "Abbrechen"

, "Save"
: "Speichern"

, "By using this service you agree to our terms and conditions"
: "Indem sie diesen Service benutzen stimmen sie unseren Allgemeinen Geschäftsbedingungen zu"

, "Please wait..."
: "Bitte warten..."

, "General terms and conditions"
: "Allgemeine Geschäftsbedingungen"

, "Use your personal link please."
: "Bitte benutzen Sie Ihren persönlichen Link."

, "We have send it to your E-Mail account again."
: "Wir haben ihn erneut an Ihre E-Mail Adresse gesendet."

, "If you did not receive the link, please contact the organiser."
: "Wenn Sie ihn nicht erhalten haben, wenden Sie sich bitte an den Organisator."

, "Password"
: "Passwort"

, "Submit"
: "Abschicken"

, "Wrong password!"
: "Flaschen Passwort!"

, "Plase log in"
: "Bitte melden Sie sich an"

, "User name"
: "Benutzername"

, "Calendar of {name}"
: "Kalender von {name}"

, "An unexpected error occurred."
: "Ein unerwarteter Fehler ist aufgetreten."

, "Relation, Relations"
: [
  "Verknüpfung"
 ,"Verknüpfungen"

]
, "Word details"
: "Word - Details"

, "Word event sheet"
: "Word - Termin-Blatt"

, "Export Events as Calendar Sheet"
: "Exportiere Termine als Kalenderblatt"

, "Excel all data"
: "Excel - Alle Daten"

, "Excel overview"
: "Excel - Übersicht"

, "OpenDocument all data"
: "OpenDocument - Alle Daten"

, "Export event data into ods spreadsheet"
: "Exportiere Termininformationenin eine ods Tabelle"

, "All events I attend"
: "Alle Termine an denen ich teilnehme"

, "Required"
: "Erforderlich"

, "Optional"
: "Freiwillig"

, "No response"
: "Keine Antwort"

, "Accepted"
: "Zugesagt"

, "Declined"
: "Abgesagt"

, "Tentative"
: "Vorläufig"

, "Awaiting response"
: "Erwartet Antwort"

, "Events I have not yet responded to"
: "Termine, die ich noch nicht beantwortet habe"

, "Declined events"
: "Abgelehnte Termine"

, "Events I have declined"
: "Termine, die ich abgelehnt haben"

, "I'm organizer"
: "Ich bin Organisator"

, "Events I'm the organizer of"
: "Termine, bei denen ich Organisator bin"

, "All my events"
: "Alle meine Termine"

, "Start Time"
: "Beginn"

, "Position on the left time axis, day and week view should start with"
: "Position auf der linken Zeit-Achse an der Tages- und Wochen-Ansichten beginnen sollen"

, "End Time"
: "Ende"

, "Position on the left time axis, day and week view should end with"
: "Position auf der linken Zeit-Achse an der Tages- und Wochen-Ansichten enden sollen"

, "Default Start Time"
: "Default Startzeit"

, "Scroll position on the left time axis, day and week view should start with"
: "Position auf der linken Zeit-Achse an der Tages- und Wochen-Ansichten beginnen sollen"

, "Visible Time"
: "Angezeigte Zeit"

, "Time to be displayed at once"
: "Wie viele Zeit auf einmal angezeigt werden sollen"

, "Default Calendar"
: "Standard Kalender"

, "The default calendar for invitations and new events"
: "Der Standard-Kalender für Einladungen und neue Termine"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on calendar startup"
: "Der Standard Favorit der beim öffnen des Kalenders geladen wird"

, "Get Notification Emails"
: "Empfangen von Benachrichtigungs-E-Mails"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "Der Grad an Aktionen über die Sie benachrichtigt werden wollen. Bitte beachten Sie, dass Organisatoren eines Termins über alle Änderungen einschließlich der Antworten von Teilnehmern benachrichtigt werden, so lange diese Option nicht auf \"Niemals\" gestellt ist."

, "Send Notifications Emails of own Actions"
: "Sende Benachrichtigungen über eigene Änderungen"

, "Get notifications emails for actions you did yourself"
: "Empfangen von Benachrichtigungen über Änderungen die selbst getätigt wurden"

, "Send Notifications Emails of tentative events"
: "Sende Benachrichtigungen für vorläufige Termine"

, "Get notifications emails of tentative events"
: "Empfangen von Benachrichtigungen über Änderungen bei vorläufigen Terminen"

, "Send Alarm Notifications Emails"
: "Sende E-Mails mit Alarm-Benachrichtigungen"

, "Get event alarms via email"
: "Erhalte Termin Alarme per Mail"

, "Enable Standard Alarm"
: "Standardalarm"

, "New events get a standard alarm as defined below"
: "Neue Termine bekommen einen Standardalarm wie unten definiert"

, "Standard Alarm Time"
: "Standardalarmzeit"

, "Minutes before the event starts"
: "Minuten bevor der Termin beginnt"

, "Default Attendee Strategy"
: "Standard Teilnehmer Strategie"

, "Default Attendee Strategy for new events"
: "Standard Teilnehmer Strategie für neue Termine"

, "Time Increment"
: "Zeit Inkrement"

, "Increment of event time steps"
: "Inkrement der Zeiteinheit für Termine"

, "Default set Events to privat"
: "Setze standartmäßig Termine auf privat"

, "If enabled every created event is always privat"
: "Wenn aktiviert, werden neue Termine immer als privat angelegt"

, "First Day of Week"
: "Erster Tag der Woche"

, "On what day the week should be starting"
: "An welchem Tag die Woche beginnen soll"

, "Default calendar strategy"
: "Standard Kalender Strategie"

, "The calendar for new events if no container is selected"
: "Der Kalender für neue Termine, wenn kein Container selektiert wurde"

, "Fixed Calendars"
: "Feste Kalender"

, "Calendars always selected regardless of all filter parameters."
: "Kalender die immer angezeigt werden, unabhängig von den eingestellten Filtern."

, "Never"
: "Nie"

, "On invitation and cancellation only"
: "Nur bei Einladung oder Absage"

, "On time changes"
: "Bei Zeitänderungen"

, "On all updates but attendee responses"
: "Bei allen Änderungen außer Teilnehmer-Anworten"

, "On attendee responses too"
: "Auch bei Teilnehmer-Antworten"

, "manage shared calendars"
: "Gemeinsame Kalender Verwalten"

, "Create new shared calendars"
: "Neuen gemeinsamen Kalender anlegen"

, "manage shared calendars favorites"
: "Gemeinsame Kalender-Favoriten verwalten"

, "Create or update shared calendars favorites"
: "Gemeinsame Kalender-Favoriten erstellen oder bearbeiten"

, "manage resources"
: "Ressourcen verwalten"

, "All Rights to administrate resources"
: "Alle Rechte um Ressourcen zu Administrieren"

, "Summary"
: "Thema"

, "View"
: "Ansicht"

, "Details"
: "Details"

, "Location"
: "Ort"

, "whole day"
: "ganztägig"

, "Saved in"
: "Gespeichert in"

, "Status"
: "Status"

, "non-blocking"
: "nicht-blockierend"

, "Private"
: "Privat"

, "Description"
: "Beschreibung"

, "Enter description"
: "Bitte geben Sie eine Beschreibung an."

, "Free Time Search"
: "Termin finden"

, "Mute Notification"
: "Benachrichtigungen unterdrücken"

, "Print Event"
: "Termin Drucken"

, "Organizer"
: "Organisator"

, "End date is not valid"
: "Endzeitpunkt ist ungültig."

, "End date must be after start date"
: "Der Endzeitpunkt muss nach dem Zeitpunkt des Beginns liegen"

, "End time is not allowed to be after the configured time."
: "Die Endzeit darf nicht hinter der konfigurierten Zeit liegen."

, "Start date is not valid"
: "Zeitpunkt den Beginns ist ungültig."

, "Start date is not allowed to be before the configured time."
: "Das Startdatum darf nicht vor der konfigurierten Zeit liegen."

, "Events"
: "Termine"

, "This event is originally stored in a calendar you don't have access to."
: "Der Ursprungstermin ist in einem Kalender gespeichert, auf den Sie keinen Zugriff haben."

, "This event is originally stored in {0}"
: "Der Ursprungstermin ist in {0} gespeichert"

, "This event is additionally displayed in your personal calendar {0}"
: "Der Termin wird zusätzlich in Ihrem persönlichen Kalender {0} angezeigt"

, "Set as definite event"
: "Definitiven Termin festlegen"

, "Set This Date as Definite Event?"
: "Dieses Datum als definitiven Termin festlegen?"

, "Do you want to close the poll and remove all other alternatives?"
: "Wollen sie diese Umfrage schließen und alle anderen Alternativen entfernen?"

, "Import Definition Success!"
: "Definition erfolgreich importiert!"

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: "Die Ical Importdefinition wurde erfolgreich erstellt! Bitte warten Sie einige Minuten, bis die Termine vom Cronjob synchronisiert wurden."

, "Choose Import File"
: "Importdatei wählen"

, "Please choose the file that contains the records you want to add to Tine 2.0"
: "Bitte wählen Sie die Datei, die die Datensätze enthält, die Sie zu Tine 2.0 hinzufügen wollen"

, "Select file containing your {0}"
: "Wählen Sie die Datei mit Ihren {0}"

, "once"
: "einmalig"

, "hourly"
: "stündlich"

, "daily"
: "täglich"

, "weekly"
: "wöchentlich"

, "Choose Remote Location"
: "Welcher entfernten Ort"

, "Please choose a remote location you want to add to Tine 2.0"
: "Wählen Sie den Ort der Quelle, die Sie zu Tine 2.0 hinzufügen wollen"

, "Username"
: "Benutzername"

, "Refresh time"
: "Aktualisierungszeit"

, "General Settings"
: "Allgemeine Einstellungen"

, "Calendar name (you need permissions to add events)"
: "Ein vorhandener Kalender, für den man über das Recht, neue Termine hinzuzufügen, verfügt"

, "What should the file you upload look like?"
: "Wie soll die Datei, die Sie hochladen, aussehen?"

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: "Tine 2.0 versteht nicht alle Dateien, die Sie möglicherweise hochladen möchten. Eventuell müssen Sie manuell die Datei so anpassen, dass sie von Tine 2.0 verarbeitet werden kann."

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: "Nachfolgend finden Sie eine Liste mit allen Import-Formaten und eine Beispieldatei, anhand derer Sie sehen, wir die Datei aussehen sollte."

, "Please select the import format of the file you want to upload"
: "Bitte wählen Sie das Import-Format für die Datei, die Sie hochladen wollen"

, "Download example file"
: "Beispieldatei herunterladen"

, "Remote / ICS"
: "Entfernt / ICS"

, "Remote / CalDAV (BETA)"
: "Entfernt / CalDAV (BETA)"

, "Upload"
: "Hochladen"

, "Choose File and Format"
: "Wähle Datei und Format"

, "Select type of source"
: "Wählen Sie den Typ der Quelle aus"

, "Please select the type of source you want to add to Tine 2.0"
: "Bitte wählen Sie die Datei, die die Datensätze enthält, die Sie zu Tine 2.0 hinzufügen wollen"

, "Importing {0}"
: "Importiere {0}"

, "Manage Resources"
: "Verwalte Ressourcen"

, "Edit Resource"
: "Ressource bearbeiten"

, "View Resource"
: "Ressource ansehen"

, "Event, Events"
: [
  "Termin"
 ,"Termine"

]
, "Calendars"
: "Kalender"

, "Quick Search"
: "Schnellsuche"

, "GENDER_Calendar"
: "male"

, "Attendee Status"
: "Teilnehmerstatus"

, "GENDER_Attendee Status"
: "male"

, "Attendee Role"
: "Teilnehmer Rolle"

, "GENDER_Attendee Role"
: "female"

, "GENDER_Status"
: "male"

, "Blocking"
: "Blockierend"

, "GENDER_Blocking"
: "other"

, "Classification"
: "Klassifikation"

, "GENDER_Classification"
: "female"

, "Unknown date"
: "Unbekanntes Datum"

, "{0} {1} o'clock"
: "{0} {1} Uhr"

, "Event (as attendee)"
: "Termin (als Teilnehmer)"

, "Event (as organizer)"
: "Termin (als Organisator)"

, "Event attendee"
: "Terminteilnehmer"

, "Attender, Attendee"
: [
  "Teilnehmer/in"
 ,"Teilnehmende"

]
, "Attendee"
: "Teilnehmer"

, "Resource, Resources"
: [
  "Ressource"
 ,"Ressourcen"

]
, "Resources"
: "Ressourcen"

, "Anyone"
: "Jeder"

, "Name"
: "Name"

, "Calendar Hierarchy/Name"
: "Kalender Hierarchie/Name"

, "Email"
: "E-Mail"

, "Maximum number of attendee"
: "Maximale Teilnehmeranzahl"

, "Type"
: "Typ"

, "Default attendee status"
: "Standard Teilnehmer Status"

, "Busy Type"
: "Belegt Typ"

, "Loading events, please wait..."
: "Bitte warten, Termine werden übertragen...."

, "Cut event"
: "Termin ausschneiden"

, "Copy Event to clipboard"
: "Termin in die Zwischenablage kopieren"

, "Stop cut / copy & paste"
: "Beende Ausschneiden / Kopieren & Einfügen"

, "Print Page"
: "Drucke Seite"

, "Loose-Leaf"
: "Ringbuch"

, "Sheet"
: "Blatt"

, "Grid"
: "Liste"

, "Timeline"
: "Zeitstrahl"

, "Day"
: "Tag"

, "Week"
: "Woche"

, "Month"
: "Monat"

, "Year"
: "Jahr"

, "Import Events"
: "Importiere Termine"

, "Paste event \"{0}\""
: "Event \"{0}\" einfügen"

, "Set my response"
: "Meine Antwort setzen"

, "Copy {0}"
: "Kopiere {0}"

, "Updating event in the past"
: "Vergangenen Termin aktualisieren"

, "Update this event"
: "Diesen Termin aktualisieren"

, "Do not update this event"
: "Diesen Termin nicht aktualisieren"

, "Creating event in the past"
: "Vergangenen Termin anlegen"

, "Create this event"
: "Diesen Termin anlegen"

, "Do not create this event"
: "Diesen Termin nicht anlegen"

, "Update this event only"
: "Nur diesen Termin aktualisieren"

, "Update this and all future events"
: "Diesen und alle zukünftigen Termine aktualisieren"

, "Update whole series"
: "Die ganze Reihe aktualisieren"

, "Update nothing"
: "Nichts aktualisieren"

, "Update Event"
: "Termin aktualisieren"

, "Please Change Selection"
: "Bitte ändern Sie Ihre Auswahl."

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "Ihre Auswahl enthält auch Wiederholungstermine. Diese müssen extra gelöscht werden!"

, "Delete Event"
: "Termin löschen"

, "Delete this event only"
: "Nur diesen Termin löschen"

, "Delete this and all future events"
: "Diesen und alle zukünftigen Termine löschen"

, "Delete whole series"
: "Komplette Reihe löschen"

, "Delete nothing"
: "Nichts löschen"

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "Möchten Sie diesen Termin wirklich löschen?"
 ,"Möchten Sie die {0} ausgewählten Termine wirklich löschen?"

]
, "Could not Print"
: "Konnte nicht drucken"

, "Sorry, your current view does not support printing."
: "Ihre aktuelle Ansicht kann leider nicht gedruckt werden."

, "Scheduling Conflict"
: "Terminüberschneidung"

, "The following attendee are busy at the requested time:"
: "Die folgenden Teilnehmer sind zur angegebenen Zeit beschäftigt:"

, "Ignore Conflict"
: "Überschneidung ignorieren"

, "Edit Event"
: "Termin bearbeiten"

, "Cancel this action"
: "Diese Aktion abbrechen"

, "Attendee/Resources"
: "Teilnehmer/Ressourcen"

, "Additional Attendees ..."
: "Weitere Teilnehmer ..."

, "Ok"
: "Ok"

, "GENDER_Attendee"
: "male"

, "Select Attendee"
: "Teilnehmer auswählen"

, "Additional Tags ..."
: "Zusätzliche Tags ..."

, "Default Status"
: "Standard Status"

, "No Access"
: ""

, "Attachments"
: ""

, "Tags"
: "Tags"

, "WK"
: "KW"

, "Originally"
: "Ursprungskalender"

, "Checking Calendar Data..."
: "Prüfe Kalenderdaten ..."

, "Reply to Recurring Event"
: "Terminserien Antwort"

, "You are responding to an recurring event. What would you like to do?"
: "Sie antworten auf eine Terminserie. Was möchten sie tun?"

, "Respond to whole series"
: "Auf die komplette Terminserie antworten"

, "Do not respond"
: "Nicht antworten"

, "The event of this message does not exist"
: "Der Termin von dieser Nachricht existiert nicht"

, "The sender is not authorised to update the event"
: "Der Absender ist nicht authorisiert den Termin zu aktualisieren"

, "This message is already processed"
: "Diese Nachricht wurde bereits verarbeitet"

, "You are not an attendee of this event"
: "Sie sind kein Teilnehmer dieses Termins"

, "This event has been deleted by the organizer"
: "Der Termin wurde vom Organisator gelöscht"

, "This event has been canceled."
: "Dieser Termin wurde abgesagt."

, "Unsupported message"
: "Nachricht wird nicht unterstützt"

, "This is an event invitation for someone else."
: "Dies ist eine Einladung für jemand anderen."

, "You have already replied to this event invitation."
: "Sie haben bereits auf diese Einladung geantwortet."

, "You received an event invitation. Set your response to:"
: "Sie haben eine Einladung zu einem Termin erhalten. Setzen Sie Ihre Antwort auf:"

, "An invited attendee responded to the invitation."
: "Ein eingeladener Teilnehmer hat auf die Einladung geantwortet."

, "Unsupported method"
: "Method wird nicht unterstützt"

, "Recurrances"
: "Wiederholungen"

, "No recurring rule defined"
: "Keine Wiederholungsregel definiert"

, "None"
: "Keine"

, "Daily"
: "Täglich"

, "Weekly"
: "Wöchentlich"

, "Monthly"
: "Monatlich"

, "Yearly"
: "Jährlich"

, "Exceptions of reccuring events can't have recurrences themselves."
: "Ausnahmen von Wiederholungsterminen können keine eigenen Wiederholungen haben."

, "at"
: "am"

, "never"
: "niemals"

, "after {0} occurrences"
: "nach {0} Terminen"

, "Except"
: "Außer"

, "during events in the calendars"
: "während Terminen in den Kalendern"

, "End"
: "Ende"

, "Until has to be after event start"
: "Terminende muss nach dem Terminanfang liegen"

, "The event is longer than the recurring interval"
: "Das Event dauert länger als das Wiederholungsintervall"

, "Every {0}. Day"
: "Jeden {0}. Tag"

, "Every {0}. Week at"
: "Jede {0}. Woche am"

, "Every {0}. Month"
: "Jeden {0}. Monat"

, "at the"
: "am"

, "first"
: "ersten"

, "second"
: "zweiten"

, "third"
: "dritten"

, "fourth"
: "vierten"

, "last"
: "letzten"

, "Every {0}. Year"
: "Jedes {0}. Jahr"

, "of"
: "im"

, "Suppress notification"
: "Benachrichtigungen unterdrücken"

, "Enter description..."
: "Bitte geben Sie eine Beschreibung an."

, "Grants"
: "Zugriffsrechte"

, "Unavailable"
: "Nicht Verfügbar"

, "New Event"
: "Neuer Termin"

, "{0}, the {1}. of {2}"
: "{0}, der {1}. {2}"

, "The summary must not be longer than 255 characters."
: "Das Thema darf nicht länger als 255 Zeichen sein."

, "The summary must have at least 1 character."
: "Das Thema muss mindestens ein Zeichen lang sein."

, "Summary too Long"
: "Zu langes Thema."

, "Summary too Short"
: "Zu kurzes Thema"

, "Mini Calendar"
: "Mini Kalender"

, "Rrule"
: "Wiederholungsregel"

, "Click here to invite another attender..."
: "Klicken Sie hier, um neue Teilnehmer einzuladen..."

, "User"
: "Benutzer"

, "Group"
: "Gruppe"

, "Member of group"
: "Gruppenmitglied"

, "Role"
: "Rolle"

, "This is the calendar where the attender has saved this event in"
: "In diesem Kalender wurde der Termin vom Teilnehmer gespeichert."

, "Click icon to change"
: "Klicke zum ändern auf das Symbol"

, "Availability of Attendee"
: "Verfügbarkeit des Teilnehmers"

, "Whole Group or each Member of Group"
: "Die ganze Gruppe oder jedes MItglied der Gruppe"

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: "Wähle \"Gruppe\" um die komplette Gruppe zu filter. Wähle \"Mitglied der Gruppe\" um nach jedem Mitglied der Gruppe zu filtern."

, "Member of Group"
: "Mitglied der Gruppe"

, "Loading Groupmembers..."
: "Lade Gruppenmitglieder..."

, "Remove Attender"
: "Teilnehmer/in entfernen"

, "Compose email"
: "E-Mail verfassen"

, "Poll URL: {0}"
: "Umfrage Link: {0}"

, "No Information"
: "Keine Angabe"

, "(as a group member)"
: "(als Gruppenmitglied)"

, "External Attendee"
: "Externer Teilnehmer"

, "no events found"
: "keine Termine gefunden"

, "Searching..."
: "Suche ..."

, "Search Event"
: "Suche Termin"

, "{0} more..."
: "{0} weitere..."

, "Colors"
: "Farben"

, "Color by Organizer Calendar"
: "Farbe nach Kalender des Organisators"

, "Color by Attendee Calendar"
: "Farbe nach Kalender des Teilnehmers"

, "Color by Tags"
: "Farbe nach Tag"

, "Color by Attendee Role"
: "Farbe nach Teilnehmerrolle"

, "Add attendee"
: "Teilnehmer hinzufügen"

, "Sort Attendee"
: "Teilnehmer sortieren"

, "Check to filter for this attendee"
: "Häkchen setzen um nach Teilnehmer zu filtern"

, "Event not found"
: "Termin nicht gefunden"

, "The Event was deleted in the meantime or you don't have access rights to it."
: "Der Termin wurde in der Zwischenzeit gelöscht oder Sie haben kein Recht diesen Termin aufzurufen."

, "Displayed in"
: "Angezeigt in"

, "Please choose the Event to add the contacts to"
: "Bitte einen Termin auswählen, dem die Kontakte hinzugefügt werden sollen"

, "Select Role"
: "Rolle wählen"

, "Select Status"
: "Status wählen"

, "Adding {0} Attendee to event"
: "Füge {0} Teilnehmer zu Termin hinzu"

, "recurring event"
: "Wiederholungstermin"

, "recurring event exception"
: "Terminserienausnahme"

, "Week {0} :"
: "Woche {0} :"

, "private classification"
: "Klassifizierung als privat"

, "has alarm"
: "hat einen Alarm"

, "has attachments"
: "hat Anhänge"

, "is part of an open poll"
: "Gehört zu einer laufenden Umfrage"

, "Resource Grant, Resource Grants"
: [
  "Ressourcen Recht"
 ,"Ressourcen Rechte"

]
, "Invite Resource"
: "Ressource einladen"

, "The grant to invite the resource to an event"
: "Das Recht die Ressource zu einem Termin einzuladen"

, "Read Resource"
: "Ressource lesen"

, "The grant to read the resource itself"
: "Das Recht die Ressource als solche zu sehen"

, "The grant to edit the resource itself"
: "Das Recht die Ressource als solche zu bearbeiten"

, "Export Resource"
: "Ressource exportieren"

, "The grant to export the resource itself"
: "Das Recht die Ressource als solche zu exportieren"

, "Sync Resource"
: "Ressource synchronisieren"

, "The grant to synchronise the resource itself"
: "Das Recht die Ressource als solche zu synchronisieren"

, "Resource Admin"
: "Ressource Administrieren"

, "The grant to administrate the resource itself"
: "Das Recht die Ressource als solche zu administrieren"

, "Add Events"
: "Termine hinzufügen"

, "The grant to directly add events into this resource calendar"
: "Das Recht Termine direkt im Ressourcen-Kalender anzulegen"

, "Read Events"
: "Termine lesen"

, "The grant to read events from this resource calendar"
: "Das Recht Termine aus Ressourcen-Kalender zu lesen"

, "Export Events"
: "Termine exportieren"

, "The grant to export events from this resource calendar"
: "Das Recht Termine aus dem Ressourcen-Kalender zu exportieren"

, "Sync Events"
: "Termine synchronisieren"

, "The grant to synchronise events from this resource calendar. Needs the grant read events"
: "Das Recht Termine aus dem Ressourcen-Kalender zu synchronisieren. Benötigt das Recht Termine lesen"

, "Events Free Busy"
: "Termine Frei/Belegt Informationen"

, "The grant to get free/busy information of events from this resource calendar"
: "Das Recht Frei/Belegt Informationen von Terminen aus dem Ressourcen-Kalender zu erhalten"

, "Edit Events"
: "Termine bearbeiten"

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: "Das Recht auf Termin-Einladungen dieser Ressource zu antworten und Termine aus dem Ressourcen-Kalender zu bearbeiten"

, "Delete Events"
: "Termine löschen"

, "The grant to delete events directly stored in this resource calendar"
: "Das Recht Termine aus dem Ressourcen-Kalender zu löschen"

, "Free Busy"
: "Frei Belegt"

, "The grant to get free/busy information of events in this calendar"
: "Das Recht Frei/Belegt Informationen von Terminen diesem Kalender zu erhalten"

, "The grant to access events marked as private in this calendar"
: "Das Recht Terminen aus diesem Kalender zu sehen die als privat markiert sind"

, "Event finder options"
: "Termin Finder Optionen"

, "Poll, Polls"
: [
  "Umfrage"
 ,"Umfragen"

]
, "Options"
: "Optionen"

, "Alternative Dates"
: "Alternative Termine"

, "Create Poll for this Event"
: "Umfrage zu diesem Termin anlegen"

, "Name for poll"
: "Name der Umfrage"

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: "Erstellen sie Terminvorschläge und wählen Sie die beste Alternative basierend auf Benutzer-Feedback."

, "Share the link below to poll for attendee status feedback."
: "Teilen sie diesen Link um Teilnehmer Feedback zu erfragen."

, "Public URL"
: "Öffentliche URL"

, "Protect poll with a password"
: "Umfrage mit Passwort schützen"

, "Only invited attendee can reply"
: "Antworten nur von eingeladenen Teilnehmern zulassen"

, "Start Date"
: "Startdatum"

, "Info"
: "Info"

, "loading alternative dates"
: "Lade die alternativen Termine"

, "Select one Event Only"
: "Nur einen Termin selektieren"

, "You need to select exactly one event as the definite event."
: "Sie müssen exakt einen Termin als definitiven Termin auswählen."

, "Setting definite event"
: "Setze den definitiven Termin"

, "Back"
: "Zurück"

, "Next"
: "Vor"

, "Searching for Free Time..."
: "Suche nachTermin..."

, "No Free Time found"
: "Kein Termin gefunden"

, "No free timeslot could be found Until {0}. Do you want to continue?"
: "Es wurde kein freier Termin-Slot bis {0} gefunden. Möchten Sie die Suche fortsetzen?"

, "Continue"
: "Fortsetzen"

, "Give up"
: "Aufgeben"

, "Free Time Search Options"
: "Termin Such Optionen"

, "Import iCal-files"
: "Importiere iCal-Dateien"

, "%s's personal calendar"
: "%ss persönlicher Kalender"

, "Start"
: "Start"

, "Priority"
: "Priorität"

, "Url"
: "Url"

, "Recurrance rule"
: "Wiederholungsregel"

, "Is all day event"
: "Ganztages-Termin"

, "Organizer timezone"
: "Zeitzone des Organisators"

, "No"
: "Nein"

, "Yes"
: "Ja"

, "Locked"
: "Geschlossen"

, "Closed"
: "Beendet"

, "unknown"
: "unbekannt"

, "This contact has been automatically added by the system as an event attender"
: "Dieser Kontakt wurde automatisch bei der Syncronisation angelegt"

, "The email address has been shortened:"
: "Die E-Mail-Adresse wurde verkürzt:"

, "Every %s day"
: "Jeden %s Tag"

, "Every %s week on"
: "Jede %s Woche am"

, "Weekly on"
: "Wöchentlich am"

, "and"
: "und"

, "Every %1$s month on the %2$s %3$s"
: "Jeden %1$s Monat am %2$s %3$s"

, "Monthly every %1$s %2$s"
: "Monatlich jeden %1$s %2$s"

, "Every %1$s month on the %2$s"
: "Jeden %1$s Monat am %2$s"

, "Monthly on the %1$s"
: "Monatlich am %1$s"

, "Yearly every %1$s %2$s of %3$s"
: "Jährlich jeden %1$s %2$s im %3$s"

, "Yearly on the %1$s of %2$s"
: "Jährlich am %1$s of %2$s"

, "second to last"
: "vorletzten"

, "fifth"
: "fünfte"

, "st"
: "."

, "nd"
: "."

, "rd"
: "."

, "th"
: "."

, "The poll \"%1$s\" has been closed."
: "Die Umfrage „%1$s“ wurde beendet."

, "The definite event is scheduled for \"%1$s\""
: "Der definitive Termin wurde auf den „%1$s“ gelegt."

, "You can review the poll results here:"
: "Sie können die Umfrageergebnisse hier einsehen:"

, "Thank you for attendening the poll \"%1$s\""
: "Danke für ihre Teilnahme an der Umfrage „%1$s“"

, "To review or edit your status please use your personal link:"
: "Zum Einsehen und Ändern ihres Status verwenden sie bitte ihren persönlichen Link:"

, "Updates"
: "Änderungen"

, "This is an event series exception."
: "Dies ist eine Terminserienausnahme"

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s wurde von  \"%2$s\" auf \"%3$s\" geändert"

, "%1$s has been invited"
: "%1$s wurde eingeladen"

, "%1$s has been removed"
: "%1$s wurde entfernt"

, "%1$s accepted invitation"
: "%1$s hat zugesagt"

, "%1$s declined invitation"
: "%1$s hat abgesagt"

, "Tentative response from %1$s"
: "%1$s hat vorläufig zugesagt"

, "No response from %1$s"
: "Keine Antwort von  %1$s"

, "\"%2$s\" response from %1$s"
: "\"%2$s\" Antwort von %1$s"

, "Link"
: "Link"

, "Event details"
: "Termin Details"

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: "Kalender, die immer angezeigt werden sollen. Ein Beispiel dafür ist ein Schulferien-Kalender."

, "Crop Days"
: "Tage begrenzen"

, "Crop calendar view configured start and endtime."
: "Konfigurierte Start- und Endzeit der begrenzten Kalenderansicht."

, "Crop Days Limit Override"
: "Begrenzte Kalenderansicht überschreiten"

, "Allow events outside start and endtime."
: "Erlaube Termin außerhalb der definierten Start- und Endzeit."

, "Week View Mouse Wheel Increment"
: "Wochenansicht Mausrad INkrement"

, "Default View for Events"
: "Standardansicht für Termine"

, "Event Status Available"
: "Verfügbare Termin Status"

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: "Verfügbare Termin Status. Bitte beachten sie, dass zusätzliche Termin Status andere Kalender-System bei Exports oder Sync beeinträchtigen können."

, "Confirmed"
: "Bestätigt"

, "Canceled"
: "Abgesagt"

, "Event Classes Available"
: "Verfügbare Termin Klassifikationen"

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: "Verfügbare Termin Klassifikationen. Bitte beachten sie, dass zusätzliche Termin Klassifikationen andere Kalender-System bei Exports oder Sync beeinträchtigen können."

, "Public"
: "Öffentlich"

, "Confidential"
: "Vertraulich"

, "Event Transparencies Available"
: "Verfügbare Termin Durchsichtigkeiten"

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: "Verfügbare Termin Durchsichtigkeiten. Bitte beachten sie, dass zusätzliche Termin Durchsichtigkeiten andere Kalender-System bei Exports oder Sync beeinträchtigen können."

, "Transparent"
: "Transparent"

, "Opaque"
: "Undurchsichtig"

, "Attendee Status Available"
: "Verfügbare Teilnehmerstatus"

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: "Verfügbare Teilnehmerstatus. Bitte beachten Sie, dass zusätzliche Werte beim Export oder der Synchronisation mit anderen Systemen nicht berücksichtigt werden könnten."

, "Attendee Roles Available"
: "Verfügbare Teilnehmerrollen"

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: "Verfügbare Teilnehmerrollen. Bitte beachten Sie, dass zusätzliche Werte beim Export oder der Synchronisation mit anderen Systemen nicht berücksichtigt werden könnten."

, "Resource Types Available"
: "Verfügbare Ressourcen Typen"

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: "Verfügbare Ressourcen Typen. Bitte beachten Sie, dass zusätzliche Frei/Belegt Typen eine Auswirkung auf andere Kalendersysteme haben können, in die exportiert oder synchronisiert wird."

, "Room"
: "Raum"

, "Board"
: ""

, "Car"
: "Auto"

, "Coffee"
: "Kaffee"

, "Homeoffice"
: ""

, "Lamp"
: "Lampe"

, "Laptop"
: ""

, "Material"
: "Material"

, "Projector"
: "Projektor"

, "Travel"
: "Reise"

, "Cable"
: "Kabel"

, "Free/Busy Types Available"
: "Verfügbare Frei/Belegt Typen"

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: "Mögliche Frei/Belegt Typen. Bitte beachten Sie, dass zusätzliche Frei/Belegt Typen eine Auswirkung auf andere Kalendersysteme haben können, in die exportiert oder synchronisiert wird."

, "Free"
: "Frei"

, "Busy"
: "Belegt"

, "Filter timeslot for CalDAV events"
: "Maximales Alter für CalDAV Termine"

, "For how long in the past (in months) the events should be synchronized."
: "Maximales Alter für Termine die synchronisiert werden dürfen (in Monaten)."

, "Filter timeslot for CalDAV events with SyncToken"
: "Filter Zeitpunkt für CalDAV Termine mit SyncToken"

, "Timeslot for event notifications"
: "Alter für Termineerinnerungen"

, "For how long in the past (in weeks) event notifications should be sent."
: "Für wie lange in der Vergangenheit (in Wochen) Termin Benachrichtigungen  versendet werden sollen."

, "Default filter period (from) for events fetched via JSON API"
: "Standard Filter Zeitraum (von) für Termine, die über die JSON API geholt werden."

, "For how long in the past (in months) the events should be fetched."
: "Für wie weit in der Vergangenheit (in Monaten) Termine geholt werden sollen."

, "Default filter period (until) for events fetched via JSON API"
: "Standard Filter Zeitraum (bis) für Termine, die über die JSON API geholt werden."

, "For how long in the future (in months) the events should be fetched."
: "Für wie weit in der Zukunft (in Monaten) Termine geholt werden sollen."

, "Disable iMIP for external organizers"
: "Deaktiviere iMIP für externe Organisatoren"

, "(CalDAV) Skip double events from personal or shared calendar"
: "(CalDAV) Doppelte Termine aus persönlichen oder geteilten Kalendern überspringen"

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: "(CalDAV) Doppelte Termine aus persönlichen oder geteilten Kalendern überspringen (\"personal\" > Termine aus Persönlichen Kalendern überspringen oder \"shared\" > Termine aus geteilten Kalendern überspringen)"

, "Send notifications to every user with edit permissions of the added resources"
: "Sende Benachrichtigungen zu allen Benutzern mit Bearbeitungsrecht an der Ressource"

, "Enabled Features"
: "Feature aktivieren"

, "Enabled Features in Calendar Application."
: "Feature in der Kalender Applikation aktivieren."

, "Calendar Split View"
: "Kalender Split Ansicht"

, "Split day and week views by attendee"
: "Unterteile Tages- und Wochen-Ansicht nach Teilnehmern"

, "Calendar Year View"
: "Kalender Jahres Ansicht"

, "Adds year view to Calendar"
: "Fügt JAhres Ansicht zum Kalender hinzu"

, "Calendar Extended Context Menu Actions"
: "Erweiterte Kalender Kontextmenü Aktionen"

, "Adds extended actions to event context menus"
: "Fügt erweiterte Kalender Kontextmenü Aktionen hinzu"

, "Color Events By"
: "Färbe Termine nach"

, "Choose event color by different criteria"
: "Wähle die Farbe von Terminen nach verschiedenen Kriterien"

, "Recur Events Except"
: "Wiederholen außer"

, "Recur Events except on certain dates"
: "Wiederholen außer an bestimmten Daten"

, "Activate Poll for Events"
: "Aktiviere Terminumfragen"

, "Create alternative Events and let users as well as externals vote for the best option."
: "Anlegen von alternativen Terminen bei denen die Nutzer und Externe über die beste Option abstimmen können."

, "Send Tentative Notifications"
: "Sende Vorläufig Benachrichtigungen"

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: "Sende Benachrichtigungen an Termin Organisatoren, wenn der Termin eien gewisse Anzahl von Tagen vor dem Stattfinden immernoch vorläufig ist."

, "Enabled"
: "Aktivirt"

, "Days Before Due Date"
: "Tage bevor Fälligkeits Datum"

, "How many days before the events due date to start send notifications."
: "Ab wie viele Tage vor dem Stattfinden eines Termins sollen Benachrichtigungen versendet werden."

, "Additional Filter"
: "Zusätzliche Filter"

, "Additional filter to limit events notifications should be send for."
: "Zusetzliche Filter um zu limitieren, wofür Termin Benachrichtigungen verschickt werden."

, "Mute Event Notifications for Polls"
: "Termin-Benachrichtigungen bei Umfragen unterdrücken"

, "Do not send invitations notifications for alternative events in an active poll."
: "Keine Einladungen für alternative Termine in Umfragen senden."

, "GTCs for polls"
: "AGB’s für Umfragen"

, "Freebusy Info"
: "Frei/Belegt Info"

, "What data the freebusy grant reveals"
: "Welche Daten das Frei/Belegt Recht sichtbar macht"

, "only date & time"
: "nur Datum & Zeit"

, "and calendar"
: "und Kalender"

, "and organizer"
: "und Organisator"

, "and resources"
: "und Ressourcen"

, "and other attendees"
: "und andere Teilnehmer"

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "Monday"
: "Montag"

, "Sunday"
: "Sonntag"

, "Me"
: "Meine"

, "Intelligent"
: "Intelligent"

, "Calendar owner"
: "Kalender Besitzer"

, "Filtered attendee"
: "Gefilterte Teilnehmer"

, "{headerDate, date, full}"
: "{headerDate, date, full}"

, "Container name / New or existing if it already exists you need permissions to add to."
: "Ein neuer Container Name oder ein bereits Vorhandener für den man über Schreibrechte verfügt."

, "or"
: "oder"

, "Is a location"
: "Ist ein Ort"

, "Errors"
: "Fehler"

, "Export as ODS"
: "Exportieren als ODS"

, "Export as ..."
: "Exportieren als ..."

, "If enabled every created event is always privat."
: "Wenn aktiviert ist jeder neu erstellte Termin privat."

, "Search for records ..."
: "Suche nach Einträgen ..."

, "Event Location"
: "Termin Ort"

, "Site"
: "Standort"

, "Event Type"
: "Terminart"

, "Do not send invitations notifications for alternatie events in an active poll."
: "Keine Einladungen für alternative Termine in aktiven Terminumfragen"

, "Poll Attendance Confirmation"
: "Terminumfrage Teilnahmebestätigung "

, "The grant to access records marked as private in this container"
: "Das Recht Termine aus dem Ressourcen-Kalender zu exportieren"

, "By using this service you agree to our"
: "Mit der Nutzung dieses Services "

, "You can not have more than one grants filter"
: "Es kann nicht mehr als einen Rechtefilter geben"

, "You can not have more than one calendar filter"
: "Es kann nicht mehr als einen Kalenderfilter geben"

, "The event got rescheduled. Set your response to:"
: "Der Termin wurde verschoben. Stellen Sie Ihre Antwort auf:"

, "Custom Selection"
: "Eigene Auswahl"

, "From"
: "Von"

, "from"
: "von"

, "Until"
: "Bis"

, "until"
: "bis"

, "Set event status"
: "Terminstatus setzen"

, "Notifications are enabled"
: "Benachrichtigungen werden nicht unterdrückt"

, "Notifications are disabled"
: "Benachrichtigungen werden unterdrückt"

, "Send Notification?"
: "Benachrichtigung senden?"

, "Changes to this event might send notifications."
: "Änderungen an diesem Termin könnten Benachrichtigungen verschicken."

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: "Änderungen an diesem Termin können Benachrichtigungen senden. Drücken Sie die Taste \"Benachrichtigung werden nicht unterdrückt\", um zu \"Benachrichtigung werden unterdrückt\" zu wechseln."

, "Color by Calendar"
: "Farbe nach Kalender"

, "Update Status for all Attendee?"
: "Status für alle Teilnehmer ändern?"

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: "Sie sind dabei, den Gesamtterminstatus (nicht nur Ihren eigenen) zu ändern. Wollen sie wirklich den Status für alle Teilnehmer ändern?"

, "Calendars to export"
: "Zu exportierende Kalender"

, "Export target"
: "Exportziel"

, "Side bar color"
: "Farbe der Seitenleiste"

, "Colors by response"
: "Farbe nach Teilnehmerstatus"

, "Colors by tags"
: "Farbe nach Tags"

, "Colors by attendee"
: "Farbe nach Teilnehmern"

, "Calendar"
: "Kalender"

, "Relation"
: "Verknüpfung"

, "Event"
: "Termin"

, "Attender"
: "Teilnehmer/in"

, "Resource"
: "Ressource"

, "Do you really want to delete this event?"
: "Möchten Sie diesen Termin wirklich löschen?"

, "Resource Grant"
: "Ressourcen Recht"

, "Poll"
: "Umfrage"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
